Changelog
=========

3.1.0
-----

  * Adding updated dockerfile and env files
  * Remove patterns include from urls for django 1.9


3.0.1
-----

  * Clean up deployment and requirements
  * Merge pull request #10 from ckinsey/master
  * Update README.md
  * Update README.md
  * Much needed pluralization love.
  * Upgrade to python3 and django 1.9
  * Updating extensions



v2.0.1
------

  * Fix Travis build testing

v2.0.0
------

  * Upgrade to Django 1.8
  * Add django rest framework to default kit
  * Change out the base templates to use materialize and no framework by default

v1.0.2
------

  * Adding a placeholder file so we create a static directory
  * Fixing makefile so renaming works on Macs

v1.0.1
------

  * Adding a license file
  * Adding a default custom user model
  * Including travis badge in project by default
  * Cleaning up requirements file

v1.0.0
------

  * Initial release
